//****************************************************************************
// @Module        ADC
// @Filename      ADC.C
// @Project       rvs.dav
// @Description   This file contains all functions that use the ADC peripheral
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

//****************************************************************************
// @Function      void ADC_vInit(void)
// @Description   This function initializes the ADC component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the ADC
//                interrupts are to be released, and the priority of the 
//                released interrupt.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void ADC_vInit(void)
{
  /// fixed channel single conversion
  /// converts channel 0
  /// ADC start bit is reset
  /// 'wait for ADDAT read mode' is enabled
  /// conversion time = TCL * 24
  /// sample time = conversion time * 1
  ADCON  = 0x0200;
}

//****************************************************************************
// @Function      uword ADC_uwReadConv(void)
// @Description   This function returns the result of a conversion.
//                This function must be called after each conversion.
//                The lower 10 bits contain the conversion result
//                while the upper 4 bits identify the converted
//                analog channel.
// @Returnvalue   conversion result
// @Date          10.04.2002 11:49:52
//****************************************************************************

uword ADC_uwReadConv(void)
{
  ADCIR = 0;
  return(ADDAT);
}
