//****************************************************************************
// @Module        Asynchronous / Synchronous Serial Interface (ASC)
// @Filename      ASC.C
// @Project       rvs.dav
// @Description   This file contains all functions that use the
//                Asynchronous / Synchronous Serial Interface.
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

//****************************************************************************
// @Function      void ASC_vInit(void)
// @Description   This function initializes the ASC component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the ASC
//                interrupts are to be released, and the priority of the 
//                released interrupt.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void ASC_vInit(void)
{
  ///  8-bit data asynchronous operation
  ///  one stop bit
  ///  ignore framing error
  ///  ignore overrun error
  ///  divide clock by reload value + constant
  ///  receiver enabled
  S0CON  = 0x0011;

  //   ASC baudrate reload register
  ///  baudrate =  9469,70 Baud
  S0BG   = 0x0040;

  P3    |= 0x0400;    //  set P3.10 output latch (TXD0)
  DP3   |= 0x0400;    /// set P3.10 direction control (TXD0 output)
  DP3   &= 0xF7FF;    /// reset P3.11 direction control (RXD0 input)


  // USER CODE BEGIN (ASC_Init,1)
	
	S0TIR = 1;
  
  // USER CODE END

  S0R    = 1;         //  enable baudrate generator
}
