//****************************************************************************
// @Module        CC1
// @Filename      CC1.C
// @Project       rvs.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C167CR-L
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the CAPCOM 1
//                peripheral
//                
//
//----------------------------------------------------------------------------
// @Date          10.04.2002 11:49:38
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (CC1_General,1)

// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (CC1_General,2)

// USER CODE END


//****************************************************************************
// @Function      void CC1_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the CAPCOM 1 component. It effects
//                all necessary configurations of the SFR, depending on the
//                selected operating mode. The configuration determines
//                whether the CAPCOM interrupts are to be released, and 
//                the priority of the released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          10.04.2002 11:49:38
//
//****************************************************************************

void CC1_vInit(void)
{
  /// ---- Timer 0 Configuration -------------
  ///  timer 0 works in counter mode, counted by:
  ///  overflow/underflow of GPT2 Timer 6 
  ///  timer 0 run bit is reset

  /// ---- Timer 1 Configuration -------------
  ///  timer 1 works in timer mode
  ///  prescaler factor is 128
  ///  timer 1 run bit is reset

  T01CON = 0x0408;
  T0     = 0x0000;    // load timer 0 register
  T1     = 0x0000;    // load timer 1 register
  T0REL  = 0x0000;    // load timer 0 reload register
  T1REL  = 0x0000;    // load timer 1 reload register


  /// ---- Capture Compare Channel 0 -------------
  ///  compare mode 2:  interrupt only
  ///  CC0 allocated to timer T0

  /// ---- Capture Compare Channel 1 -------------
  ///  disable capture compare channel 1

  /// ---- Capture Compare Channel 2 -------------
  ///  disable capture compare channel 2

  /// ---- Capture Compare Channel 3 -------------
  ///  disable capture compare channel 3

  CCM0 = 0x0006;
  CC0  = 0x0000;  // load CC0 register


  /// ---- Capture Compare Channel 4 -------------
  ///  disable capture compare channel 4

  /// ---- Capture Compare Channel 5 -------------
  ///  disable capture compare channel 5

  /// ---- Capture Compare Channel 6 -------------
  ///  disable capture compare channel 6

  /// ---- Capture Compare Channel 7 -------------
  ///  disable capture compare channel 7

  /// ---- Capture Compare Channel 8 -------------
  ///  disable capture compare channel 8

  /// ---- Capture Compare Channel 9 -------------
  ///  disable capture compare channel 9

  /// ---- Capture Compare Channel 10 -------------
  ///  disable capture compare channel 10

  /// ---- Capture Compare Channel 11 -------------
  ///  disable capture compare channel 11
  ///  enable CC8 interrupt
  ///  CC8 interrupt priority level(ILVL) = 13
  ///  CC8 interrupt group level (GLVL) = 2
  CC8IC = 0x0076;

  ///  enable CC9 interrupt
  ///  CC9 interrupt priority level(ILVL) = 13
  ///  CC9 interrupt group level (GLVL) = 3
  CC9IC = 0x0077;


  /// ---- Capture Compare Channel 12 -------------
  ///  disable capture compare channel 12

  /// ---- Capture Compare Channel 13 -------------
  ///  disable capture compare channel 13

  /// ---- Capture Compare Channel 14 -------------
  ///  disable capture compare channel 14

  /// ---- Capture Compare Channel 15 -------------
  ///  disable capture compare channel 15

  // USER CODE BEGIN (CC1_Init,1)

  // USER CODE END

}




// USER CODE BEGIN (CC1_General,3)

// USER CODE END

