//**********************************************************************************************
// @Filename      DataFunctions.c
// @Project       rvs.dav
// @Description   This file contains all functions for data manipulation
// @Date          10.04.2002

/***********************************************************************************************/
// Includes

#include "main.h"
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

/***********************************************************************************************/
// Definition of data storage struct

struct data
{
    short year,month,day,hour,minute,second; //GPS Time Data	12 Byte
    unsigned long lap; //Latitude postion						4
    unsigned long lop;	//Longitude position					4
    char lah;	//Latitude Hemisphere							1
    char loh;	//Longitude Hemisphere							1	
    char ps;	//Position Status								1
    char ewvd;	//East-West velocity direction					1
    short hper;	//Horizontal position error						2
    short ewvm;	//East-West velocity magnitude					2
    short nsvm;	//Noth-South velocity magnitude					2
    short wd;	//Winddirection									2
    short wvm;	//Wind velocity magnitude						2
    char nsvd;	//Wind North-South velocity direction			1
};																//gesamt 36 Byte

/***********************************************************************************************/
// Globale Variables

//recindex->index of struct_array for recording; sndindex->index of struct_array for sending; i->standard counter variable; count->counter variable from StringParse
int recindex=0,sndindex=0,i,count,isread=0;
int wd, wvm; 
char buffer[9];	//buffer String
char gpsdata[55];	//String with original GPS Data
struct data struct_array[NUMBEROFDATASTRUCTS];	//Array in wich the structs are stored (NUMBEROFDATASTRUCTS is defined in MAIN.H)

/***********************************************************************************************/
// Prototypes of all functions

void StoreData(void);
void ReadData(void);
void GetData(char*);
void SendData(int);
void DataCpy(int);
void GetWindData();
void StringParse(char*,char*,int,int);

/*****************************************************************************************/
// Insert a new element to the list

void StoreData()
{
	isread = 0;	//Set to 0, to indicate that no new data was read
	if(recindex<NUMBEROFDATASTRUCTS) //Check for Memory Overflow (Memory is the same as struct_array[index])
	{
		IO_vResetPin(P2_2);	//Debug Information
		GetData(gpsdata);
		DataCpy(recindex);
		recindex = recindex + 1;
		struct_array[recindex].ps = '!'; //Set the GPS status info to ! to mark the last data struct in the array
	}
	else //(index==NUMBEROFDATASTRUCTS) Memory full
	{
		isrunning = HALT;	//Set isrunning to HALT
		GT1_vStopTmr(T2);	//Stop the Sampling Timer
		IO_vResetPin(P2_2);	//Set the ERROR LED
		IO_vSetPin(P2_1);	//Reset the START/STOP LED
		_idle_();			//Set the System to idle
	}
}

/*******************************************************************************************/
// Get the data from the GPS device (and the windsensors)

void GetData(char *gpsdata)
{
	while(1)
	{
		if(getchar() == '@')	//Check for first character of GPS string (weil Timer und GPS nicht gleichzeitig)
		{
			gets(gpsdata,55);	//Get the string after the first character is dedected
			GetWindData();
			IO_vSetPin(P2_2);
			break;		
		}
	}
}

/****************************************************************************************/
//Get the data from the windsensors

void GetWindData()
{
	//Get the winddirection
	ADC_vStartConv();	//Start a new conversion
	wd = (int) ((ADC_uwReadConv() & 0x03FF) * 360.0 / 1024.0);		//Cut off the two LSB, calculate the value in degree, and convert to integer

	//Get the wind velocity magnitude
	wvm = (int) ((wvmbuffer / (WINDRPM * 0.833)) * 10);	//Multiply with 10 because 12.4 is transfered as 124, and then convert to int
}

/*********************************************************************************************/
// Copy data to the struct

void DataCpy(int index)	//This function uses recindex
{
    //Copy data to the struct
	//Timedata
	StringParse(gpsdata,buffer,0,1);
	struct_array[index].year = atoi(buffer);
	StringParse(gpsdata,buffer,2,3);
	struct_array[index].month = atoi(buffer);
	StringParse(gpsdata,buffer,4,5);
	struct_array[index].day = atoi(buffer);
	StringParse(gpsdata,buffer,6,7);
	struct_array[index].hour = atoi(buffer);
	StringParse(gpsdata,buffer,8,9);
	struct_array[index].minute = atoi(buffer);
	StringParse(gpsdata,buffer,10,11);
	struct_array[index].second = atoi(buffer);

	//Latitude data
	StringParse(gpsdata,buffer,12,12);
	struct_array[index].lah = buffer[0];
	StringParse(gpsdata,buffer,13,19);
	struct_array[index].lap = atol(buffer);
		
	//Longitude data
	StringParse(gpsdata,buffer,20,20);
	struct_array[index].loh = buffer[0];
	StringParse(gpsdata,buffer,21,28);
	struct_array[index].lop = atol(buffer);

	//GPS status info
	StringParse(gpsdata,buffer,29,29);
	struct_array[index].ps = buffer[0];
	
	//Check for invalid GPS data
    if(strpbrk(gpsdata,"_")!=0) struct_array[index].ps = 'i'; //Set GPS status info to invalid
	
	StringParse(gpsdata,buffer,30,32);
	struct_array[index].hper = atoi(buffer);

	//East-West velocity data
	StringParse(gpsdata,buffer,39,39);
	struct_array[index].ewvd = buffer[0];
	StringParse(gpsdata,buffer,40,43);
	struct_array[index].ewvm = atoi(buffer);

	//North-South velocity data
	StringParse(gpsdata,buffer,44,44);
	struct_array[index].nsvd = buffer[0];
	StringParse(gpsdata,buffer,45,48);
	struct_array[index].nsvm = atoi(buffer);

	//Wind data
	struct_array[index].wd = wd;
	struct_array[index].wvm = wvm;
}

/****************************************************************************************/
// String Parse Function
// The characters from strposstart to strposend are copied from quelle to buffer

void StringParse(char *quelle,char *buffer,int strposstart,int strposend)
{
	count=0,i=0;

	for(i=strposstart; i<=strposend; i++)
	{
		buffer[count] = quelle[i];	//Copy the selected characters to buffer
		count++;
	}
	buffer[strposend-strposstart+1]='\0';	//Copy the string termination character
}

/****************************************************************************************/
/****************************************************************************************/
/****************************************************************************************/
// Read elements from the list

void ReadData()
{
	if(isread == 0)		//If the data has not been read yet, read it
	{
		while(struct_array[sndindex].ps != '!' && sndindex<NUMBEROFDATASTRUCTS)	//Read the data structs until ! is found in the GPS status info or the last index is reached
		{
			SendData(sndindex);
			sndindex = sndindex + 1;
		}
		sndindex = 0;		//Reset the Send Index
		isread = 1;			//Set to 1, to indicate that the data have been read (Set to 0 in Function StoreData)
	}
	isrunning = HALT;	//When all data have been sent, stop the system
	IO_vSetPin(P2_1);	//Reset the START/STOP LED
	IO_vSetPin(P2_2);	//Reset the ERROR LED
}

/******************************************************************************************/
// Write the data to the PC

void SendData(int index)	//This function uses sndindex
{
	//Send time data
	printf("%i.%i.%i.%i.%i.%i",struct_array[index].year,struct_array[index].month,struct_array[index].day,struct_array[index].hour,struct_array[index].minute,struct_array[index].second);
	//Send latitude data
	printf(".%c%li",struct_array[index].lah,struct_array[index].lap);
	//Send longitude data
	printf(".%c%li",struct_array[index].loh,struct_array[index].lop);
	//Send GPS status info
	printf(".%c%i",struct_array[index].ps,struct_array[index].hper);
	//Send East/West velocity data
	printf(".%c%i",struct_array[index].ewvd,struct_array[index].ewvm);
	//Send North/South velocity data
	printf(".%c%i",struct_array[index].nsvd,struct_array[index].nsvm);
	//Send wind data
	printf(".%i.%i",struct_array[index].wd,struct_array[index].wvm);
	//printf("  index: %i",index);
	//Send NEWLINE
	printf("\n");
}
