//****************************************************************************
// @Module        General Purpose Timer Unit 1
// @Filename      GT1.C
// @Project       rvs.dav
// @Description   This file contains all functions that use the GPT1 unit.
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (GT1_General,2)

	int tmrcount = 0; //This variable counts the timer interrupts (1 interrupt at 833ms)of the sampling timer
	float wvmbuffer = 0;

// USER CODE END


//****************************************************************************
// @Function      void GT1_vInit(void)
// @Description   This function initializes the GPT1 component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the GPT1
//                interrupts are to be released, and the priority of the 
//                released interrupt.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void GT1_vInit(void)
{
  /// ------------ Timer 3 Control Register ----------
  ///  timer 3 works in counter mode
  ///  positive transition (rising edge) on T3IN
  ///  counter 3 run bit is reset
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  ///  alternate output (toggle T3OUT) function is disabled 
  T3CON = 0x0009;
  T3    = 0x0000;  //  load timer 3 register

  DP3  &= 0xFFBF;  /// reset P3.6 direction control (T3IN input)

  /// ---------- Timer 2 Control Register ----------
  ///  timer 2 works in timer mode
  ///  prescaler factor is 128
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T2CON = 0x0004;
  T2    = 0x0000;  //  load timer 2 register

  ///  enable timer 2 interrupt
  ///  timer 2 interrupt priority level(ILVL) = 11
  ///  timer 2 interrupt group level (GLVL) = 3
  T2IC = 0x006F;

  /// ---------- Timer 4 Control Register ----------
  ///  timer 4 works in timer mode
  ///  prescaler factor is 8
  ///  timer 4 run bit is reset
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T4CON = 0x0000;
  T4    = 0x0000;  //  load timer 4 register



  // USER CODE BEGIN (GT1_Init,1)

  // USER CODE END


  T2R = 0;         //   set timer 2 run bit 
}


//****************************************************************************
// @Function      void GT1_viIsrTmr2(void) interrupt T2INT
// @Description   This is the interrupt service routine for the GPT1 timer 2.
//                It is called up when the timer 2 register over or under-
//                flows or if timer 3 is reloaded with the content of timer 2
//                (external signal or T3 over/underflow) or if an external
//                capture event arrives.
//                
//                Please note that you have to add application specific
//                code to this function.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void GT1_viIsrTmr2(void) interrupt T2INT
{
  // USER CODE BEGIN (GT1_IsrTmr2,1)

	tmrcount = tmrcount + 1;

	wvmbuffer = GT1_uwReadTmr(T3); 	//Read the Counter Register from Timer3
	GT1_vLoadTmr(T3,0x0000);	//Reset the Counter Register of Timer3
	
	if(tmrcount==SAMPLINGTIME) //Compare the number of timer interrupst with predefined value (defined in MAIN.H)
	{
		StoreData(); //Call StoreData from data_functions.c
		tmrcount = 0;	//Reset tmrcount
		GT1_vLoadTmr(T3,0x0000);	//Reset the Counter Register of Timer3
	}
	
  // USER CODE END
}
