//****************************************************************************
// @Module        General Purpose Timer Unit 1
// @Filename      GT1.H
// @Project       rvs.dav
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Prototypes of global functions
//****************************************************************************

void GT1_vInit(void);

//****************************************************************************
// @Macros
//****************************************************************************

//****************************************************************************
// @Macro         GT1_vStartTmr(TimerNr)
// @Description   This macro starts the selected GPT1 timer. The timer continues
//                to count from where it had stopped
//                The following definitions are available for TimerNr:
//                TIMER_2
//                TIMER_3
//                TIMER_4
// @Parameters    the name of the timer to be started
// @Date          10.04.2002 11:49:52
//****************************************************************************

#define GT1_vStartTmr(TimerNr)  GT1_vStart(TimerNr,R)
#define GT1_vStart(TimerNr,R) TimerNr##R = 1

//****************************************************************************
// @Macro         GT1_vStopTmr(TimerNr)
// @Description   This macro stops the selected GPT1 timer. The contents of
//                the timer register remain unchanged.
//                The following definitions are available for TimerNr:
//                TIMER_2
//                TIMER_3
//                TIMER_4
// @Parameters    the name of the timer to be stopped
// @Date          10.04.2002 11:49:52
//****************************************************************************

#define GT1_vStopTmr(TimerNr)  GT1_vStop(TimerNr,R)
#define GT1_vStop(TimerNr,R) TimerNr##R = 0                     

//****************************************************************************
// @Macro         GT1_uwReadTmr(TimerNr)
// @Description   This macro returns the contents of the selected GPT1 timer.
//                The timer is not stopped. Access of the CPU to the
//                registers of the timer is of higher priority than a timer
//                increment, a reload or a capture event.
//                The following definitions are available for TimerNr:
//                TIMER_2
//                TIMER_3
//                TIMER_4
// @Returnvalue   current 16-bit value of the timer
// @Parameters    the name of the timer to be readed
// @Date          10.04.2002 11:49:52
//****************************************************************************

#define GT1_uwReadTmr(TimerNr) TimerNr

//****************************************************************************
// @Macro         GT1_vLoadTmr(TimerNr,Value)
// @Description   This macro loads the selected GPT1 timer with the forwarded
//                value. The timer is not stopped. The access of the CPU to
//                the registers of the timers is of higher priority than a
//                timer increment, a reload or a capture event.
//                The following definitions are available for TimerNr:
//                TIMER_2
//                TIMER_3
//                TIMER_4
// @Parameters    the name of the timer to be loaded
// @Parameters    16-bit value to be loaded
// @Date          10.04.2002 11:49:52
//****************************************************************************

#define GT1_vLoadTmr(TimerNr,Value) TimerNr = Value

//***************************************************************************
// @Defines
//***************************************************************************

#define TIMER_2 T2
#define TIMER_3 T3
#define TIMER_4 T4

//***************************************************************************
// @Interrupt vectors
//***************************************************************************

#define T2INT   0x22
