//****************************************************************************
// @Module        Interrupt Controller
// @Filename      INT.C
// @Project       rvs.dav
// @Description   This file contains all selected ISRs for fast external
//                interrupts and general functions for interrupts and PEC.
// @Date          10.04.2002 11:49:53

//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

//***************************************************************************
// @Global Variables
//***************************************************************************


// USER CODE BEGIN (IR_General,2)
	
	BOOLEAN isrunning = HALT;
	BOOLEAN mode = REC;

// USER CODE END


//****************************************************************************
// @Function      void INT_vInit(void)
// @Description   This function initializes the fast external
//                interrupts 0 - 7. It effects all necessary
//                configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the 
//                external interrupts are to be released, and the priority 
//                of the released interrupt.
// @Date          10.04.2002 11:49:53
//****************************************************************************

void INT_vInit(void)
{

  /// ------- external interrupt 0 edge selection -------
  ///  external interrupt 0 on positive edge (rising) at pin P2.8

  /// ------- external interrupt 1 edge selection -------
  ///  external interrupt 1 on positive edge (rising) at pin P2.9

  EXICON = 0x0005;
  DP2   &= 0xFCFF;


  ///  enable external 0 interrupt
  ///  external 0 interrupt priority level(ILVL) = 13
  ///  external 0 interrupt group level (GLVL) = 2
  CC8IC = 0x0076;

  ///  enable external 1 interrupt
  ///  external 1 interrupt priority level(ILVL) = 13
  ///  external 1 interrupt group level (GLVL) = 3
  CC9IC = 0x0077;
}


//****************************************************************************
// @Function      void INT_viIsrEx0(void) interrupt CC8INT
// @Description   This is the interrupt service routine for the external
//                interrupt 0 (P2.8).
//                It is called when the configured event is captured.
//                
//                Please note that you have to add application specific
//                code to this function.
// @Date          10.04.2002 11:49:53
//****************************************************************************

void INT_viIsrEx0(void) interrupt CC8INT
{
  // USER CODE BEGIN (IR_IsrEx0,1)
	
	// Switching between record / write mode
	// mode == REC -> record mode ; mode == WRI -> write mode
	if(isrunning == HALT)	//Change the mode only when no transmission is done
	{
		if(mode == REC)
		{
			IO_vResetPin(P2_0);	//Set the MODE LED
			mode = WRI; // Switch from record mode to write mode
		}
		else
		{
			IO_vSetPin(P2_0);	//Reset the MODE LED
			mode = REC; // Switch from write mode to record mode
		}
	}
	
  // USER CODE END
}

//****************************************************************************
// @Function      void INT_viIsrEx1(void) interrupt CC9INT
// @Description   This is the interrupt service routine for the external
//                interrupt 1 (P2.9).
//                It is called when the configured event is captured.
//                
//                Please note that you have to add application specific
//                code to this function.
// @Date          10.04.2002 11:49:53
//****************************************************************************

void INT_viIsrEx1(void) interrupt CC9INT
{
  // USER CODE BEGIN (IR_IsrEx1,1)

  	// Switch betwenn Start / Stop
	// isrunning == RUN -> Start ; isrunning == HALT -> Stop
   	if(isrunning == HALT)
	{
		IO_vResetPin(P2_1);	//Set the START/STOP LED
		isrunning = RUN;	//Switch from HALT to RUN
	
		if(mode == REC)
		{
			GT1_vLoadTmr(T3,0x0000); //Reset the Counter Register of Timer3
			GT1_vStartTmr(T2);	//Start the sampling timer
			GT1_vStartTmr(T3);	//Start the wind velocity counter
		}
		
		if(mode == WRI)
		{
			ReadData();	//Call ReadData from data_functions.c
		}	
	}
	else	//if(isrunning == RUN)
	{
		IO_vSetPin(P2_1);	//Reset the START/STOP LED
		isrunning = HALT;	//Switch from RUN to HALT	
		GT1_vStopTmr(T2);	//Stop the sampling timer
		GT1_vStopTmr(T3);	//Stop the wind velocity timer
		_idle_();	//Set the System to idle
	}
	
  // USER CODE END
}
