//****************************************************************************
// @Module        Main
// @Filename      MAIN.C
// @Project       rvs.dav
// @Controller    Infineon C167CR-L
// @Compiler      KEIL C166
// @Codegenerator DAvE 2-0-0
// @Description   This file contains the Project initialization function.
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

//****************************************************************************
// @Function      void Project_Init(void)
// @Description   This function initializes the microcontroller.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void Project_Init(void)
   {
   /// --- initialization of the SYSCON Register ---
   ///- 256 words system stack
   ///- the internal ROM area is mapped to segment 0
   ///- the segmentation is enabled (CSP is saved/restored during interrupt entry/exit)
   ///- the internal ROM is disabled: accesses to the ROM area use the external bus
   ///- the pin #BHE (byte high enable) is enabled
   ///- the system clock output is disabled
   ///- the pins #WR and #BHE retain their normal functions
   ///- the on-chip X-Peripherals are enabled and can be accessed
   ///- accesses to the XBUS peripherals are done internally
   ///- external accesses to the XBUS peripherals are disabled
   
   /// --- initialization of the BUSCON 0-4 and ADRRSEL Registers 1-4 ---
   
   /// ---------- external bus 0 is enabled ----------
   ///- 16-bit multiplexed bus
   ///- memory cycle time control: 15 waitstates
   ///- read/write delay control: activate signal 1 TCL after falling edge of ALE  
   ///- signal configuration: disable READY signal 
   ///- chip select mode: address chip select 
   ///- memory tristate control: 1 waitstate
   ///- ALE lengthening control: lengthened ALE signal
   
   
   // initializes the IO ports
   IO_vInit();
   
   // initializes the ASC peripheral
   ASC_vInit();
   
   // initializes the ADC peripheral
   ADC_vInit();
   
   // initializes the general purpose timer unit 1
   GT1_vInit();
   
   // initializes the external interrupts
   INT_vInit();
   
   // USER CODE BEGIN (Project_Init,1)
   
   // USER CODE END
   
   // globally enable interrupts
   IEN = 1;
   }

//****************************************************************************
// @Function      void main(void)
// @Description   This is the main function.
// @Date          10.04.2002 11:49:52
//****************************************************************************

void main(void)
   {
   Project_Init();
   
   // USER CODE BEGIN (Main,2)
         
         IO_vWritePort(P2,0x0007);       //Set all LEDs to default values
   while (1)
      {
      _idle_();
      }
   // USER CODE END
   }
