//****************************************************************************
// @Module        Main
// @Filename      MAIN.H
// @Project       rvs.dav
// @Controller    Infineon C167CR-L
// @Compiler      KEIL C166
// @Codegenerator DAvE 2-0-0
// @Description   This is the include header file for all other modules.
// @Date          10.04.2002 11:49:52

//****************************************************************************
// @Defines
//****************************************************************************

#define ulong unsigned long
#define uword unsigned int
#define ubyte unsigned char

#define KEIL
#define BFLD   _bfld_


// USER CODE BEGIN (MainHeader,0)

#define RUN 1 
#define HALT 0
#define REC 1
#define WRI 0 
#define BOOLEAN short

//This variable controls the sampling time (a value of 1 stands for 833ms)
//Note that this variable has a great effect on the memory usage!!
//Low value -> big amount of memory needed, better accuracy
//High value -> low amount of memory needed, but less accuracy
// RealSamplingTime = 0.833seconds x SAMPLINGTIME
// 5 -> every 4.1s a value from the GPS is taken -> ca. 15 Values per minute -> 540 Byte per minute
// 10 -> every 8.3s a value from the GPS is taken -> ca. 7 Values per minute -> 252 Byte per minute
// 20 -> every 16.6s a value from the GPS is taken -> ca. 4 Values per minute -> 144 Byte per minute
#define SAMPLINGTIME 10

//This variable controls the number of data structs that can be stored
//This value is depending on the available memory
//Per stored struct 36Byte of memory are used
//Note that you need 3 kByte from the memory for programm internal use!
//max. Value = 1704 -> 61,344 kByte of data at a system with 64 kByte RAM
#define NUMBEROFDATASTRUCTS 623	//623, 1078, 1252, 1331, 1704

//The whole storage time is calculated as follows:
//StorageTime = NUMBEROFDATASTRUCTS / (60 / (0.833seconds x SAMPLNGTIME))	[minutes]
//Note that these values are not exact! In reality these values can be a little bit different from the calculated values!

//This value is used to configure the windsensor for the wind velocity
//Must be set to the RPM the windsensor rotates at a windvelocity of 1 m/s
#define WINDRPM 10

// USER CODE END

//****************************************************************************
// @Project Includes
//****************************************************************************

#include <reg167.h>
#include <intrins.h>

#include "IO.H"
#include "ASC.H"
#include "ADC.H"
#include "GT1.H"
#include "INT.H"

// USER CODE BEGIN (MainHeader,1)

#include "DataFunctions.h"

extern float wvmbuffer;
extern BOOLEAN isrunning;
extern BOOLEAN mode;

// USER CODE END

